#=========================================================================#
#                               RSTR-comment                              #
#=========================================================================#

# Comment on:
# Swan, C.M., and B.L. Brown. 2017. Metacommunity theory meets restoration: 
# isolation may mediate how ecological communities respond to stream 
# restoration. Ecological Applications 27: 2209–2219.

# Author: David Murray-Stoker (dstoker92@gmail.com)
# Last Updated: 5 May 2020

## Table of Contents
# Line   28: Load Packages and Data
# Line   70: Community Diversity Calculations
# Line   79: -Taxa Richness & Diversity
# Line  109: -Spatial Variation 
# Line  236: -Temporal Variation
# Line  303: Taxa Richness & Diversity ANOVA
# Line  550: Spatial Variation ANOVA
# Line  630: Temporal Variation ANOVA
# Line  703: Figures
# Line 1162: End of Script


#=========================================================================#
#                          Load Packages & Data                           #
#==========================================================================
library(nlme)
library(vegan)

## Load the tidyverse
library(tidyverse) 

## Set woring directory
setwd("~/Documents/Research/RSTR-comment")

## Source code for helper functions and themes for creating figures
source("~/Documents/R Materials/R Script/DMS-ggplot2-supplement.R")

## Read in invertebrate data
invertebrate.data <- read.csv("Swan_Brown_Invertebrate_Data.csv")

## Rename columns due to personal preference and ease of interpretation in
## model summaries
names(invertebrate.data)[c(2, 4:5)] <- c("Season", "Treatment", "Order")

## Full data (all sites included)
full.data <- invertebrate.data

## Remove site 227, season = spring, treatment = restoration (row 21 in 
## full.data), as there is no corresponding sample from the adjacent reach
full.data <- full.data[-21, ]
# Note: this site was removed to allow for the paired comparisons for each
# site, season, and treatment combination. In other words, if the the paired
# observation is absent from the data, the paired comparison cannot be made; 
# therefore, I removed the site from the re-analyses. The site was kept in
# the re-analyses of the full and reduced models of Swan and Brown (2018).

## Revised data (only sites receiving at least bank stabilization and in-channel
## manipulation treatments)
revised.data <- full.data[full.data$Site.ID != 24 &
													full.data$Site.ID != 21 &
													full.data$Site.ID != 179 &
													full.data$Site.ID != 196, ]


#=========================================================================#
#                    Community Diversity Calculations                     #
#==========================================================================


## Calculate (1) taxa richness and evenness, (2) spatial variation, and (3)
## temporal variation of invertebrate communities as outlined by Swan & Brown 2017.


#-------------------------------------------------------------------------#
#                         Taxa Richness & Diversity                       #
#--------------------------------------------------------------------------


## Calculate taxonomic richness (number of taxa present) and taxonomic diversity,
## as measured by the Shannon diversity index, for the full and revised sites data.


## Full data--------------------------------------------------------------#

## Calculate taxa richness for each site
full.data$taxa.richness <- specnumber(full.data[, 7:89])

## Calculate Shannon diversity
full.data$shannon.diversity <- diversity(full.data[, 7:89], index = "shannon")

## Calculata taxa richness for each site for the full and reduced models by Swan and Brown 2018.
invertebrate.data$taxa.richness <- specnumber(invertebrate.data[, 7:89])


## Revised data-----------------------------------------------------------#

## Calculate taxa richness for each site
revised.data$taxa.richness <- specnumber(revised.data[, 7:89])

## Calculate Shannon diversity
revised.data$shannon.diversity <- diversity(revised.data[, 7:89], index = "shannon")


#-------------------------------------------------------------------------#
#                            Spatial Variation                            #
#--------------------------------------------------------------------------


## Calculate Gower dissimilarity between restored and adjacent reaches. Gower 
## dissimilarity (specifically, the modified Gower index as outlined by Anderson
## et al. 2006) will be calculated for the restored and adjacent communities
## of each site for each sampling date. To do this, the data must be reorganized
## so the index can be calculated for each site-by-date combination. 
## Communities from the restored and adjacent reaches will be subset from the 
## data, bound into a single community matrix, and the modified Gower index 
## will be calculated.

## For a description of the modified Gower index, please see:
# Anderson, M.J., K.E. Ellingsen, and B.H. McArdle. 2006. Multivariate 
# dispersion as a measure of beta diversity. Ecology Letters 9:683–693.


## Full data--------------------------------------------------------------#

## Add group identifier to the full data
full.data$group.identifier <- paste(full.data$Site.ID, full.data$Season)

## Subset data by reach
full.restored.reaches <- full.data[full.data$Treatment == "Restoration", c(92, 1:2, 5, 7:89)]
full.adjacent.reaches <- full.data[full.data$Treatment == "Adjacent", c(92, 7:89)]

## Bind into single dataframe
full.spatial.variation.data <- cbind(full.restored.reaches, full.adjacent.reaches)

## Restored data = columns 5:87, adjacent data = columns 89:171

## Set empty dataframe for gower distances
gower.data <- data.frame("gower.distance" = numeric())

## Define function for sequentially calculating gower distances between communities
## in restored and adjacent reaches
site.gower.function <- function(j){
  
  ## Set to 50 for full data
  for(x in 1:50){
    
    ## Set restored community
    restored.community <- j[x, 5:87]
    
    ## Set adjacent community
    adjacent.community <- j[x, 89:171]
    
    ## Bind into single matrix
    community.matrix <- rbind(restored.community, adjacent.community)
    
    ## Calculate gower distance
    gower.distance <- vegdist(decostand(community.matrix, method = "log", logbase = 5), 
    													method = "altGower", binary = FALSE)
    #decostand(varespec, "log")
    gower.data[x, ] <- gower.distance
  }
  
  ## Set vector of gower distances
  site.gower.data <- as.data.frame(gower.data)
}

## Apply the function to the full data
full.gower.data <- (site.gower.function(full.spatial.variation.data))

## Create data for gower distances for later analyses
full.spatial.variation.data$gower <- full.gower.data$gower.distance

## Susbet only needed columns
full.spatial.variation.data <- full.spatial.variation.data[, c(2:4, 172)]


## Revised data-----------------------------------------------------------#

## Add group identifier to the revised data
revised.data$group.identifier <- paste(revised.data$Site.ID, revised.data$Season)

## Subset reaches
revised.restored.reaches <- revised.data[revised.data$Treatment == "Restoration", c(92, 1:2, 5, 7:89)]
revised.adjacent.reaches <- revised.data[revised.data$Treatment == "Adjacent", c(92, 7:89)]

## Bind into single dataframe
revised.spatial.variation.data <- cbind(revised.restored.reaches, revised.adjacent.reaches)

## Restored data = columns 5:87, adjacent data = columns 89:171

## Set empty dataframe for gower distances
gower.data <- data.frame("gower.distance" = numeric())

## Define function for calculating gower distances between communities
## in restored and adjacent reaches
site.gower.function <- function(j){
  
  ## Set to 35 for full data
  for(x in 1:35){
    
    ## Set restored community
    restored.community <- j[x, 5:87]
    
    ## Set adjacent community
    adjacent.community <- j[x, 89:171]
    
    ## Bind into single matrix
    community.matrix <- rbind(restored.community, adjacent.community)
    
    ## Calculate gower distance
    gower.distance <- vegdist(decostand(community.matrix, method = "log", logbase = 5),
    													method = "altGower", binary = FALSE)
    
    gower.data[x, ] <- gower.distance
  }
  
  ## Set vector of gower distances
  site.gower.data <- as.data.frame(gower.data)
}

## Apply the function to the revised data
revised.gower.data <- as.data.frame(site.gower.function(revised.spatial.variation.data))

## Attach to revised data
revised.spatial.variation.data$gower <- revised.gower.data$gower.distance

## Subset only needed columns
revised.spatial.variation.data <- revised.spatial.variation.data[, c(2:4, 172)]


#-------------------------------------------------------------------------#
#                            Temporal Variation                           #
#--------------------------------------------------------------------------


## Calculate beta dispersion as a measure of temporal stability/variation.
## The data are reorganized to assign groups by site, treatment, and order,
## The Bray-Curtis dissimilarity index is calculated for each site from the
## whole community matrix (as ostensibly described by Swan and Brown 2017), 
## and then the beta dispersion is calculated for each site. Beta dispersion 
## is quantified as the average distance to the group centroid. Swan and Brown (2017)
## reported using the group centroid, yet the results presented in the erratum
## were derived from the group median, despite never mentioning this change in 
## analysis and this only being found if the supplemental code was accessed.

## In other words and as an example, site 24 was sampled in the spring, summer,
## fall, and winter for both restored and adjacent reaches. Beta dispersion (i.e. 
## temporal variation) will be calculated as the variation between each sample
## (i.e. between spring, summer, fall, and winter) for each site, such as site
## 24, restored reach, and spring, summer, fall, and winter samples.


## Full data--------------------------------------------------------------#

## Bray-Curtis distances among samples
full.BC.dis <- vegdist(full.data[, 7:89], method = "bray")

## Grouped by site, treatment (restored or unrestored), and order (headwater or mainstem)
full.BC.groups <- paste(full.data$Site.ID, full.data$Treatment, full.data$Order)

## Calculate multivariate dispersions
full.temporal.variation.distances <- betadisper(full.BC.dis, group = full.BC.groups, type = "centroid")$distances
full.temporal.variation           <- data.frame(full.temporal.variation.distances, full.data$Site.ID, 
																				        full.data$Treatment, full.data$Order)
colnames(full.temporal.variation) <- c("variation", "Site.ID", "Treatment", "Order")
full.temporal.variation.data      <- aggregate(variation ~ Site.ID + Treatment, FUN = mean,
																				       data = full.temporal.variation)
## Define list of orders
full.order.list <- factor(c("MS", "MS", "MS", "HW", "MS", "MS", "MS", "HW",
														"HW", "HW", "MS", "MS", "HW", "MS", "MS", "MS",
														"HW", "MS", "MS", "MS", "HW", "HW", "HW", "MS", 
														"MS", "HW"))
full.temporal.variation.data$Order <- full.order.list


## Revised data-----------------------------------------------------------#

## Bray-Curtis distances among samples
revised.BC.dis <- vegdist(revised.data[, 7:89], method = "bray")

## Grouped by site, treatment (restored or unrestored), and order (headwater or mainstem)
revised.BC.groups <- paste(revised.data$Site.ID, revised.data$Treatment, revised.data$Order)

## Calculate multivariate dispersions
revised.temporal.variation.distances <- betadisper(revised.BC.dis, group = revised.BC.groups, type = "centroid")$distances
revised.temporal.variation           <- data.frame(revised.temporal.variation.distances, revised.data$Site.ID, 
																				           revised.data$Treatment, revised.data$Order)
colnames(revised.temporal.variation) <- c("variation", "Site.ID", "Treatment", "Order")
revised.temporal.variation.data      <- aggregate(variation ~ Site.ID + Treatment, FUN = mean,
																				          data = revised.temporal.variation)
## Define list of orders
revised.order.list <- factor(c("MS", "MS", "HW", "MS", "HW", "HW", "MS", "MS",
															 "HW", "MS", "MS", "HW", "MS", "HW", "HW", "MS", 
															 "MS", "HW"))
revised.temporal.variation.data$Order <- revised.order.list


#=========================================================================#
#                      Taxa Richness & Diversity ANOVA                    #
#==========================================================================


## Compare taxa richness and diversity by season, treatment, and stream order,
## as well as all two- and three-way interactions. Model assumptions are 
## inspected graphically. Transformations are used when necessary to meet 
## model assumptions.

## Given (1) the drastic unbalanced design of the treatment levels (38 HW, 62 MS),
## (2) that unequal variance observed in exploratory analyses, and (3) interaction
## terms were hypothesized to be significant, Type III sums of squares will 
## be used for all ANOVAs in this re-analysis. Swan and Brown (2017, 2018) 
## utilized Type I sums of squares, but those are inappropriate for such an
## unbalanced design and when the interaction terms are significant.

## The primary ANOVA for my  analyses includes Site.ID as a random effect.
## Swan and Brown (2017) did not specifiy if a random effect was used in their
## ANOVAs; in the erratum, it was clarified that a random effect was fitted
## for the taxonomic richness ANOVA.


## Full data--------------------------------------------------------------#

## Set factors in the data
full.data$Site.ID   <- as.factor(full.data$Site.ID)
full.data$Season    <- as.factor(full.data$Season)
full.data$Treatment <- as.factor(full.data$Treatment)
full.data$Order     <- as.factor(full.data$Order)

## Boxplots to evaluate the distribution of the data
boxplot(taxa.richness ~ Season * Treatment * Order, data = full.data)
# Considerable variation among groups, suggesting unequal variance

boxplot(log(taxa.richness) ~ Season * Treatment * Order, data = full.data)
# Unequal variance is still present but greatly reduced with ln transformation

## Full taxa richness ANOVA
full.richness.anova <- lme(log(taxa.richness) ~ Season * Treatment * Order,
													 random = ~1|Site.ID,
													 contrasts = list(Season = contr.treatment(n = 4), 
													 								  Treatment = contr.treatment(n = 2),
													 								  Order = contr.treatment(n = 2)),
									         data = full.data)
anova(full.richness.anova, type = "sequential") # Type I sums of squares
anova.lme(full.richness.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(full.richness.anova)
plot(full.richness.anova)
hist(resid(full.richness.anova)) # Some left skew to the residuals
plot(residuals(full.richness.anova))


## Effect sizes calculated as: 
# partial eta^2 = [df_between * F(df_between)]/[df_between * F(df_between) + df_within]
# S = season, T = treatment, O = order

# Calculation derived from Cohen 1973, Eta-squared and partial eta-squared
# in fixed factor ANOVA designs

## Full richness ANOVA partial eta-squareds:
(full.richness.ES.S     <- (3 * 1.99052)/(3 * 1.99052 + 73)) # 0.07561659
(full.richness.ES.T     <- (1 * 0.72967)/(1 * 0.72967 + 73)) # 0.009896559
(full.richness.ES.O     <- (1 * 1.41914)/(1 * 1.41914 + 11)) # 0.1142704
(full.richness.ES.S_T   <- (3 * 0.04476)/(3 * 0.04476 + 73)) # 0.001836075
(full.richness.ES.S_O   <- (3 * 1.64059)/(3 * 1.64059 + 73)) # 0.06316296
(full.richness.ES.T_O   <- (1 * 0.30790)/(1 * 0.30790 + 73)) # 0.004200093
(full.richness.ES.S_T_O <- (3 * 0.08326)/(3 * 0.08326 + 73)) # 0.003409976


## Boxplot to evaluate the distribution of the data
boxplot(shannon.diversity ~ Season * Treatment * Order, data = full.data)
# Considerable variation among groups, suggesting unequal variance

boxplot(sqrt(shannon.diversity) ~ Season * Treatment * Order, data = full.data)
# Unequal variance is still present but greatly reduced with square-root transformation

## Full taxa diversity ANOVA
full.diversity.anova <- lme(sqrt(shannon.diversity) ~ Season * Treatment * Order,
													  random = ~1|Site.ID,
													  contrasts = list(Season = contr.treatment(n = 4), 
													 								   Treatment = contr.treatment(n = 2),
													 								   Order = contr.treatment(n = 2)),
													 data = full.data)
anova(full.diversity.anova, type = "sequential") # Type I sums of squares
anova.lme(full.diversity.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(full.diversity.anova)
plot(full.diversity.anova)
hist(resid(full.diversity.anova)) # Good distribution of the residuals
plot(residuals(full.diversity.anova))

## Full diversity ANOVA partial eta-squareds:
(full.diversity.ES.S     <- (3 * 12.26703)/(3 * 12.26703 + 73)) # 0.3351614
(full.diversity.ES.T     <- (1 * 0.08806)/(1 * 0.08806 + 73))   # 0.001204848
(full.diversity.ES.O     <- (1 * 2.07276)/(1 * 2.07276 + 11))   # 0.1585557
(full.diversity.ES.S_T   <- (3 * 0.32283)/(3 * 0.32283 + 73))   # 0.01309328
(full.diversity.ES.S_O   <- (3 * 2.47729)/(3 * 2.47729 + 73))   # 0.09239957
(full.diversity.ES.T_O   <- (1 * 0.13923)/(1 * 0.13923 + 73))   # 0.00190363
(full.diversity.ES.S_T_O <- (3 * 0.31342)/(3 * 0.31342 + 73))   # 0.01271648


## Revised data-----------------------------------------------------------#

## Set factors in the data
revised.data$Site.ID   <- as.factor(revised.data$Site.ID)
revised.data$Season    <- as.factor(revised.data$Season)
revised.data$Treatment <- as.factor(revised.data$Treatment)
revised.data$Order     <- as.factor(revised.data$Order)

## Boxplot to evaluate the distribution of the data
boxplot(taxa.richness ~ Season * Treatment * Order, data = revised.data)
# Considerable variation among groups, suggesting unequal variance

boxplot(log(taxa.richness) ~ Season * Treatment * Order, data = revised.data)
# Unequal variance is still present but again greatly reduced with ln transformation

## Revised taxa richness ANOVA
revised.richness.anova <- lme(log(taxa.richness) ~ Season * Treatment * Order,
													    random = ~1|Site.ID,
													    contrasts = list(Season = contr.treatment(n = 4), 
													 								     Treatment = contr.treatment(n = 2),
													 								     Order = contr.treatment(n = 2)),
													    data = revised.data)
anova(revised.richness.anova, type = "sequential") # Type I sums of squares
anova.lme(revised.richness.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(revised.richness.anova)
plot(revised.richness.anova)
hist(resid(revised.richness.anova)) # Good distribution of residuals, some left skew
plot(residuals(revised.richness.anova))

## Revised richness ANOVA partial eta-squareds:
(revised.richness.ES.S     <- (3 * 1.41080)/(3 * 1.41080 + 47)) # 0.08261178
(revised.richness.ES.T     <- (1 * 0.39785)/(1 * 0.39785 + 47)) # 0.008393841
(revised.richness.ES.O     <- (1 * 0.00410)/(1 * 0.00410 + 7))  # 0.0005853714
(revised.richness.ES.S_T   <- (3 * 0.14314)/(3 * 0.14314 + 47)) # 0.009053874
(revised.richness.ES.S_O   <- (3 * 0.55322)/(3 * 0.55322 + 47)) # 0.03410751
(revised.richness.ES.T_O   <- (1 * 1.37548)/(1 * 1.37548 + 47)) # 0.02843341
(revised.richness.ES.S_T_O <- (3 * 0.14853)/(3 * 0.14853 + 47)) # 0.0093916


## Boxplot to evaluate the distribution of the data
boxplot(shannon.diversity ~ Season * Treatment * Order, data = revised.data)
# Considerable variation among groups, suggesting unequal variance

boxplot(sqrt(shannon.diversity) ~ Season * Treatment * Order, data = revised.data)
# Unequal variance is still present but greatly reduced with square-root transformation

## Revised taxa diversity ANOVA
revised.diversity.anova <- lme(sqrt(shannon.diversity) ~ Season * Treatment * Order,
															 random = ~1|Site.ID,
															 contrasts = list(Season = contr.treatment(n = 4), 
																							  Treatment = contr.treatment(n = 2),
																							  Order = contr.treatment(n = 2)),
															 data = revised.data)
anova(revised.diversity.anova, type = "sequential") # Type I sums of squares
anova.lme(revised.diversity.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(revised.diversity.anova)
plot(revised.diversity.anova)
hist(resid(revised.diversity.anova)) # Good distribution of the residuals
plot(residuals(revised.diversity.anova))

## Revised diversity ANOVA partial eta-squareds:
(revised.diversity.ES.S     <- (3 * 10.99879)/(3 * 10.99879  + 47)) # 0.4124733
(revised.diversity.ES.T     <- (1 * 0.08511)/(1 * 0.08511 + 47))    # 0.001807578
(revised.diversity.ES.O     <- (1 * 0.25329)/(1 * 0.25329 + 7))     # 0.0349207
(revised.diversity.ES.S_T   <- (3 * 0.28362)/(3 * 0.28362 + 47))    # 0.0177815
(revised.diversity.ES.S_O   <- (3 * 1.27154)/(3 * 1.27154 + 47))    # 0.07506934
(revised.diversity.ES.T_O   <- (1 * 0.91747)/(1 * 0.91747 + 47))    # 0.01914688
(revised.diversity.ES.S_T_O <- (3 * 0.14924)/(3 * 0.14924 + 47))    # 0.00943607


## Swan and Brown Erratum-------------------------------------------------#

## Models presented by Swan and Brown in the erratum. One ANOVA model has all
## singular effects and two- and three-way interactions. The reduced model
## does not have the two-way interaction between season and reach and the 
## three-way interaction between season, order, and reach.

## Reminder: Swan and Brown (2017., 2018) did not remove the site for which
## there was not a paired sample from the adjacent reach.

## Set factors in the data
invertebrate.data$Site.ID   <- as.factor(invertebrate.data$Site.ID)
invertebrate.data$Season    <- as.factor(invertebrate.data$Season)
invertebrate.data$Treatment <- as.factor(invertebrate.data$Treatment)
invertebrate.data$Order     <- as.factor(invertebrate.data$Order)

## Swan and Brown full model (FM)
Swan.Brown.FM <- lme(taxa.richness ~ Season * Treatment * Order,
										 random = ~1|Site.ID, 
										 contrasts = list(Season = contr.treatment(n = 4), 
										 								  Treatment = contr.treatment(n = 2),
										 								  Order = contr.treatment(n = 2)),
					           data = invertebrate.data)
anova(Swan.Brown.FM, type = "sequential") # Type I sums of squares
anova(Swan.Brown.FM, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(Swan.Brown.FM)
plot(Swan.Brown.FM)
hist(resid(Swan.Brown.FM)) # Decent distribution of the residuals
plot(residuals(Swan.Brown.FM))

## Swan and Brown full model ANOVA partial eta-squareds:
(Swan.Brown.FM.ES.S     <- (3 * 2.47755)/(3 * 2.47755 + 74)) # 0.09127359
(Swan.Brown.FM.ES.T     <- (1 * 1.40902)/(1 * 1.40902 + 74)) # 0.01868503
(Swan.Brown.FM.ES.O     <- (1 * 0.92467)/(1 * 0.92467 + 11)) # 0.07754261
(Swan.Brown.FM.ES.S_T   <- (3 * 0.15210)/(3 * 0.15210 + 74)) # 0.006128427
(Swan.Brown.FM.ES.S_O   <- (3 * 2.35922)/(3 * 2.35922 + 74)) # 0.08729482
(Swan.Brown.FM.ES.T_O   <- (1 * 0.97886)/(1 * 0.97886 + 74)) # 0.01305515
(Swan.Brown.FM.ES.S_T_O <- (3 * 0.07061)/(3 * 0.07061 + 74)) # 0.002854397


## Swan and Brown reduced model (RM)
Swan.Brown.RM <- lme(taxa.richness ~ Treatment + Order + Season
										                 + Season:Order + Order:Treatment,
										 contrasts = list(Season = contr.treatment(n = 4), 
										 								  Treatment = contr.treatment(n = 2),
										 								  Order = contr.treatment(n = 2)),
										 random = ~1|Site.ID,
						         data = invertebrate.data)
anova(Swan.Brown.RM, type = "sequential") # Type I sums of squares
anova(Swan.Brown.RM, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(Swan.Brown.RM)
plot(Swan.Brown.RM)
hist(resid(Swan.Brown.RM)) # Good distribution of the residuals
plot(residuals(Swan.Brown.RM))
abline(h = 0, lty = 2)

## Swan and Brown reduced model ANOVA partial eta-squareds:
(Swan.Brown.RM.ES.S   <- (3 * 4.35795)/(3 * 4.35795 + 80)) # 0.1404675
(Swan.Brown.RM.ES.T   <- (1 * 4.84371)/(1 * 4.84371 + 80)) # 0.05708979
(Swan.Brown.RM.ES.O   <- (1 * 1.57879)/(1 * 1.57879 + 11)) # 0.1255121
(Swan.Brown.RM.ES.S_O <- (3 * 4.10478)/(3 * 4.10478 + 80)) # 0.1333957
(Swan.Brown.RM.ES.T_O <- (1 * 3.52951)/(1 * 3.52951 + 80)) # 0.04225465


#=========================================================================#
#                          Spatial Variation ANOVA                        #
#==========================================================================


## Compare Gower dissimilarity by season, order, and their interaction. Model
## assumptions are inspected graphically. Transformations are used when 
## necessary to meet model assumptions.


## Full data--------------------------------------------------------------#

## Set factors in the data
full.spatial.variation.data$Site.ID   <- as.factor(full.spatial.variation.data$Site.ID)
full.spatial.variation.data$Season    <- as.factor(full.spatial.variation.data$Season)
full.spatial.variation.data$Order     <- as.factor(full.spatial.variation.data$Order)

## Boxplots to evaluate the distribution of the data
boxplot(gower ~ Season * Order, data = full.spatial.variation.data)
# There is variation among groups, suggesting unequal variance

boxplot(log(gower) ~ Season * Order, data = full.spatial.variation.data)
# Transformation greatly reduced the unequal variance

## Full spatial variation ANOVA
full.spatial.variation.anova <- lme(log(gower) ~ Season * Order,
																		random = ~1|Site.ID,
																		contrasts = list(Season = contr.treatment(n = 4),
																										 Order = contr.treatment(n = 2)),
                                    data = full.spatial.variation.data)
anova(full.spatial.variation.anova, type = "sequential") # Type I sums of squares
anova.lme(full.spatial.variation.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(full.spatial.variation.anova)
plot(full.spatial.variation.anova)
hist(resid(full.spatial.variation.anova)) # Very good distribution of residuals
plot(residuals(full.spatial.variation.anova))

## Full spatial variation ANOVA partial eta-squareds:
(full.spatial.ES.S   <- (3 * 1.1463761)/(3 * 1.1463761 + 31)) # 0.09986107
(full.spatial.ES.O   <- (1 * 0.0620887)/(1 * 0.0620887 + 11)) # 0.005612747
(full.spatial.ES.S_O <- (3 * 1.3556905)/(3 * 1.3556905 + 31)) # 0.1159798


## Revised data-----------------------------------------------------------#

## Set factors in the data
revised.spatial.variation.data$Site.ID   <- as.factor(revised.spatial.variation.data$Site.ID)
revised.spatial.variation.data$Season    <- as.factor(revised.spatial.variation.data$Season)
revised.spatial.variation.data$Order     <- as.factor(revised.spatial.variation.data$Order)

## Boxplots to evaluate the distribution of the data
boxplot(gower ~ Season * Order, data = revised.spatial.variation.data)
# There is variation among groups, suggesting unequal variance

boxplot(log(gower) ~ Season * Order, data = revised.spatial.variation.data)
# Transformation greatly reduced the unequal variance

## Revised spatial variation ANOVA
revised.spatial.variation.anova <- lme(log(gower) ~ Season * Order,
																		   random = ~1|Site.ID,
																		   contrasts = list(Season = contr.treatment(n = 4),
																										    Order = contr.treatment(n = 2)),
																		   data = revised.spatial.variation.data)
anova(revised.spatial.variation.anova, type = "sequential") # Type I sums of squares
anova.lme(revised.spatial.variation.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(revised.spatial.variation.anova)
plot(revised.spatial.variation.anova)
hist(resid(revised.spatial.variation.anova)) # Decent distribution of residuals
plot(residuals(revised.spatial.variation.anova))

## Revised spatial variation ANOVA partial eta-squareds:
(revised.spatial.ES.S   <- (3 * 0.4246701)/(3 * 0.4246701 + 20)) # 0.05988576
(revised.spatial.ES.O   <- (1 * 0.0074719)/(1 * 0.0074719 + 7))  # 0.001066276
(revised.spatial.ES.S_O <- (3 * 0.3059063)/(3 * 0.3059063 + 20)) # 0.0438728


#=========================================================================#
#                           Temporal Variation ANOVA                      #
#==========================================================================


## Compare temporal variation by treatment, order, and their interaction. Model
## assumptions are inspected graphically.


## Full data--------------------------------------------------------------#

## Set factors in the data
full.temporal.variation.data$Site.ID   <- as.factor(full.temporal.variation.data$Site.ID)
full.temporal.variation.data$Treatment <- as.factor(full.temporal.variation.data$Treatment)
full.temporal.variation.data$Order     <- as.factor(full.temporal.variation.data$Order)

## Boxplots to evaluate the distribution of the data
boxplot(variation ~ Treatment * Order, data = full.temporal.variation.data)
# There is variation among groups, but nothing of too much concern

## Full temporal variation ANOVA
full.temporal.variation.anova <- lme(variation ~ Treatment * Order,
																		 random = ~1|Site.ID,
																		 contrasts = list(Treatment = contr.treatment(n = 2),
																										  Order = contr.treatment(n = 2)),
																		 data = full.temporal.variation.data)
anova(full.temporal.variation.anova, type = "sequential") # Type I sums of squares
anova.lme(full.temporal.variation.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(full.temporal.variation.anova)
plot(full.temporal.variation.anova)
hist(resid(full.temporal.variation.anova)) # Some left skew to the residuals
plot(residuals(full.temporal.variation.anova))

## Full temporal variation ANOVA partial eta-squareds:
(full.temporal.ES.T   <- (1 * 1.90600)/(1 * 1.90600 + 11)) # 0.1476832
(full.temporal.ES.O   <- (1 * 0.03005)/(1 * 0.03005 + 11)) # 0.002724376
(full.temporal.ES.T_O <- (1 * 2.05404)/(1 * 2.05404 + 11)) # 0.157349


## Revised data-----------------------------------------------------------#

## Set factors in the data
revised.temporal.variation.data$Site.ID   <- as.factor(revised.temporal.variation.data$Site.ID)
revised.temporal.variation.data$Treatment <- as.factor(revised.temporal.variation.data$Treatment)
revised.temporal.variation.data$Order     <- as.factor(revised.temporal.variation.data$Order)

## Boxplots to evaluate the distribution of the data
boxplot(variation ~ Treatment * Order, data = revised.temporal.variation.data)
# There is variation among groups, but nothing of too much concern

## Revised temporal variation ANOVA
revised.temporal.variation.anova <- lme(variation ~ Treatment * Order,
																		    random = ~1|Site.ID,
																		    contrasts = list(Treatment = contr.treatment(n = 2),
																		 								     Order = contr.treatment(n = 2)),
																		    data = revised.temporal.variation.data)
anova(revised.temporal.variation.anova, type = "sequential") # Type I sums of squares
anova.lme(revised.temporal.variation.anova, type = "marginal", adjustSigma = FALSE) # Type III sums of squares

## Check model assumptions
qqnorm(revised.temporal.variation.anova)
plot(revised.temporal.variation.anova)
hist(resid(revised.temporal.variation.anova)) # Too few samples to draw inference
plot(residuals(revised.temporal.variation.anova))

## Revised temporal variation ANOVA partial eta-squareds:
(revised.temporal.ES.T   <- (1 * 2.69333)/(1 * 2.69333 + 7)) # 0.2778539
(revised.temporal.ES.O   <- (1 * 0.95697)/(1 * 0.95697 + 7)) # 0.1202681
(revised.temporal.ES.T_O <- (1 * 4.71777)/(1 * 4.71777 + 7)) # 0.4026167


#=========================================================================#
#                                 Figures                                 #
#==========================================================================

## Get summary data for figures

## Taxonomic Richness-----------------------------------------------------#
full.richness.summary <- plyr::ddply(full.data, 
															 c("Season", "Order", "Treatment"), 
															 summarise,
															 N    = sum(!is.na(taxa.richness)),
															 mean = mean(taxa.richness, na.rm = TRUE),
															 sd   = sd(taxa.richness, na.rm = TRUE),
															 se   = sd / sqrt(N),
															 LL   = quantile(taxa.richness, 0.025),
															 UL   = quantile(taxa.richness, 0.975)
)

revised.richness.summary <- plyr::ddply(revised.data, 
																	c("Season", "Order", "Treatment"), 
																	summarise,
																	N    = sum(!is.na(taxa.richness)),
																	mean = mean(taxa.richness, na.rm = TRUE),
																	sd   = sd(taxa.richness, na.rm = TRUE),
																	se   = sd / sqrt(N),
																	LL   = quantile(taxa.richness, 0.025),
																	UL   = quantile(taxa.richness, 0.975)
)

full.site.richness.summary <- plyr::ddply(full.data, 
																		c("Site.ID", "Order", "Treatment"), 
																		summarise,
																		N    = sum(!is.na(taxa.richness)),
																		mean = mean(taxa.richness, na.rm = TRUE),
																		sd   = sd(taxa.richness, na.rm = TRUE),
																		se   = sd / sqrt(N),
																		LL   = quantile(taxa.richness, 0.025),
																		UL   = quantile(taxa.richness, 0.975)
)

revised.site.richness.summary <- plyr::ddply(revised.data, 
																			 c("Site.ID", "Order", "Treatment"), 
																			 summarise,
																			 N    = sum(!is.na(taxa.richness)),
																			 mean = mean(taxa.richness, na.rm = TRUE),
																			 sd   = sd(taxa.richness, na.rm = TRUE),
																			 se   = sd / sqrt(N),
																			 LL   = quantile(taxa.richness, 0.025),
																			 UL   = quantile(taxa.richness, 0.975)
)


## Taxonomic Diversity----------------------------------------------------#
full.diversity.summary <- plyr::ddply(full.data, 
																c("Season", "Order", "Treatment"), 
																summarise,
																N    = sum(!is.na(shannon.diversity)),
																mean = mean(shannon.diversity, na.rm = TRUE),
																sd   = sd(shannon.diversity, na.rm = TRUE),
																se   = sd / sqrt(N),
																LL   = quantile(shannon.diversity, 0.025),
																UL   = quantile(shannon.diversity, 0.975)
)

revised.diversity.summary <- plyr::ddply(revised.data, 
																	 c("Season", "Order", "Treatment"), 
																	 summarise,
																	 N    = sum(!is.na(shannon.diversity)),
																	 mean = mean(shannon.diversity, na.rm = TRUE),
																	 sd   = sd(shannon.diversity, na.rm = TRUE),
																	 se   = sd / sqrt(N),
																	 LL   = quantile(shannon.diversity, 0.025),
																	 UL   = quantile(shannon.diversity, 0.975)
)

full.site.diversity.summary <- plyr::ddply(full.data, 
																		 c("Site.ID", "Order", "Treatment"), 
																		 summarise,
																		 N    = sum(!is.na(shannon.diversity)),
																		 mean = mean(shannon.diversity, na.rm = TRUE),
																		 sd   = sd(shannon.diversity, na.rm = TRUE),
																		 se   = sd / sqrt(N),
																		 LL   = quantile(shannon.diversity, 0.025),
																		 UL   = quantile(shannon.diversity, 0.975)
)

revised.site.diversity.summary <- plyr::ddply(revised.data, 
																				c("Site.ID", "Order", "Treatment"), 
																				summarise,
																				N    = sum(!is.na(shannon.diversity)),
																				mean = mean(shannon.diversity, na.rm = TRUE),
																				sd   = sd(shannon.diversity, na.rm = TRUE),
																				se   = sd / sqrt(N),
																				LL   = quantile(shannon.diversity, 0.025),
																				UL   = quantile(shannon.diversity, 0.975)
)


## Spatial Variation------------------------------------------------------#
full.spatial.summary <- plyr::ddply(full.spatial.variation.data, 
															c("Season", "Order"), 
															summarise,
															N    = sum(!is.na(gower)),
															mean = mean(gower, na.rm = TRUE),
															sd   = sd(gower, na.rm = TRUE),
															se   = sd / sqrt(N),
															LL   = quantile(gower, 0.025),
															UL   = quantile(gower, 0.975)
)

revised.spatial.summary <- plyr::ddply(revised.spatial.variation.data, 
																 c("Season", "Order"), 
																 summarise,
																 N    = sum(!is.na(gower)),
																 mean = mean(gower, na.rm = TRUE),
																 sd   = sd(gower, na.rm = TRUE),
																 se   = sd / sqrt(N),
																 LL   = quantile(gower, 0.025),
																 UL   = quantile(gower, 0.975)
)


## Temporal Variation-----------------------------------------------------#
full.temporal.summary <- plyr::ddply(full.temporal.variation.data, 
															 c("Treatment", "Order"), 
															 summarise,
															 N    = sum(!is.na(variation)),
															 mean = mean(variation, na.rm = TRUE),
															 sd   = sd(variation, na.rm = TRUE),
															 se   = sd / sqrt(N),
															 LL   = quantile(variation, 0.025),
															 UL   = quantile(variation, 0.975)
)

revised.temporal.summary <- plyr::ddply(revised.temporal.variation.data, 
																	c("Treatment", "Order"), 
																	summarise,
																	N    = sum(!is.na(variation)),
																	mean = mean(variation, na.rm = TRUE),
																	sd   = sd(variation, na.rm = TRUE),
																	se   = sd / sqrt(N),
																	LL   = quantile(variation, 0.025),
																	UL   = quantile(variation, 0.975)
)


## Set "dodge" value so points do not overlap in figures
dodge <- position_dodge(0.45)

## Color palette
viridis.2 <- viridis(n = 2)


#-------------------------------------------------------------------------#
#                         Taxonomic Richness Figure                       #
#--------------------------------------------------------------------------

## Full richness HW plot
full.richness.HW.plot <- ggplot(data = full.richness.summary[full.richness.summary$Order == "HW", ],
																aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	labs(y = "Taxonomic Richness") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(5, 10, 15), limits = c(0, 17.5)) +
	remove.x.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(A) Headwaters")

## Full richness MS plot
full.richness.MS.plot <- ggplot(data = full.richness.summary[full.richness.summary$Order == "MS", ], 
																aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(5, 10, 15), limits = c(0, 17.5)) +
	labs(x = "Season", y = "Taxonomic Richness") +
	basic.theme +
	theme(legend.position = "none") +
	ggtitle("(C) Mainstems")

## Revised richness HW plot
revised.richness.HW.plot <- ggplot(data = revised.richness.summary[revised.richness.summary$Order == "HW", ], 
																	 aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(5, 10, 15), limits = c(0, 17.5)) +
	remove.all.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(B) Headwaters")

## Revised richness MS plot
revised.richness.MS.plot <- ggplot(data = revised.richness.summary[revised.richness.summary$Order == "MS", ], 
																	 aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") + 
	labs(x = "Season") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(5, 10, 15), limits = c(0, 17.5)) +
	remove.y.axis.labels +
	ggtitle("(D) Mainstems")


## Arrange the panel figure
richness.figure <- grid.arrange(full.richness.HW.plot, revised.richness.HW.plot,
																full.richness.MS.plot, revised.richness.MS.plot,
																nrow = 2, ncol = 2)

## Export the figure
ggsave("Figure 1-Taxonomic Richness.pdf", 
			 plot = richness.figure,
			 device = "pdf",
			 path = "/Users/dms/Documents/Research/RSTR-comment/Figures/",
			 width = 9,
			 height = 9,
			 units = "in",
			 dpi = 600)


#-------------------------------------------------------------------------#
#                        Taxonomic Diversity Figure                       #
#--------------------------------------------------------------------------

## Full diversity HW plot
full.diversity.HW.plot <- ggplot(data = full.diversity.summary[full.diversity.summary$Order == "HW", ], 
																 aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	labs(y = "Taxonomic Diversity") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1, 2), limits = c(0, 2.5)) +
	remove.x.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(A) Headwaters")

## Full diversity MS plot
full.diversity.MS.plot <- ggplot(data = full.diversity.summary[full.diversity.summary$Order == "MS", ], 
																 aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1, 2), limits = c(0, 2.5)) +
	labs(x = "Season", y = "Taxonomic Diversity") +
	basic.theme +
	theme(legend.position = "none") +
	ggtitle("(C) Mainstems")

## Revised diversity HW plot
revised.diversity.HW.plot <- ggplot(data = revised.diversity.summary[revised.diversity.summary$Order == "HW", ], 
																		aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1, 2), limits = c(0, 2.5)) +
	remove.all.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(B) Headwaters")

## Revised diversity MS plot
revised.diversity.MS.plot <- ggplot(data = revised.diversity.summary[revised.diversity.summary$Order == "MS", ], 
																		aes(x = Season, y = mean, shape = Treatment)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") + 
	labs(x = "Season") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1, 2), limits = c(0, 2.5)) +
	remove.y.axis.labels +
	ggtitle("(D) Mainstems")


## Arrange the panel figure
diversity.figure <- grid.arrange(full.diversity.HW.plot, revised.diversity.HW.plot,
																 full.diversity.MS.plot, revised.diversity.MS.plot,
																 nrow = 2, ncol = 2)

## Export the figure
ggsave("Figure 2-Taxonomic Diversity.pdf", 
			 plot = diversity.figure,
			 device = "pdf",
			 path = "/Users/dms/Documents/Research/RSTR-comment/Figures/",
			 width = 9,
			 height = 9,
			 units = "in",
			 dpi = 600)


#-------------------------------------------------------------------------#
#                         Spatial Variation Figure                        #
#--------------------------------------------------------------------------

## Full spatial plot
full.spatial.plot <- ggplot(data = full.spatial.summary, 
														aes(x = Season, y = mean, shape = Order)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	labs(x = "Season", y = "Spatial Dissimilarity") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1.0, 2.0), limits = c(0, 2.0)) +
	basic.theme +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(A)")

## Revised spatial plot
revised.spatial.plot <- ggplot(data = revised.spatial.summary, 
															 aes(x = Season, y = mean, shape = Order)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") + 
	labs(x = "Season", y = "Spatial Dissimilarity") +
	scale_x_discrete(limits = c("Spring", "Summer", "Fall", "Winter")) +
	scale_y_continuous(breaks = c(0, 1.0, 2.0), limits = c(0, 2.0)) +
	remove.y.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	ggtitle("(B)")


## Arrange the panel figure
spatial.variation.figure <- grid.arrange(full.spatial.plot, revised.spatial.plot,
																				 nrow = 1, ncol = 2)

## Export the figure
ggsave("Figure 3-Spatial Variation.pdf", 
			 plot = spatial.variation.figure,
			 device = "pdf",
			 path = "/Users/dms/Documents/Research/RSTR-comment/Figures/",
			 width = 8,
			 height = 4.5,
			 units = "in",
			 dpi = 600)


#-------------------------------------------------------------------------#
#                        Temporal Variation Figure                        #
#--------------------------------------------------------------------------

## Full temporal plot
full.temporal.plot <- ggplot(data = full.temporal.summary, 
														 aes(x = Treatment, y = mean, shape = Order)) +
	geom_point(size = 6, position = dodge, color = "#440154FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#440154FF") + 
	labs(x = "Treatment", y = "Temporal Variability") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	scale_y_continuous(breaks = c(0, 0.25, 0.5), limits = c(0, 0.5)) +
	basic.theme +
	theme(legend.position = c(0.85, 0.125)) +
	ggtitle("(A)")

## Revised temporal plot
revised.temporal.plot <- ggplot(data = revised.temporal.summary, 
																aes(x = Treatment, y = mean, shape = Order)) +
	geom_point(size = 6, position = dodge, color = "#FDE725FF") +
	geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
								width = 0.2, size = 1, position = dodge, color = "#FDE725FF") + 
	labs(x = "Treatment", y = "Temporal Variability") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	scale_y_continuous(breaks = c(0, 0.25, 0.5), limits = c(0, 0.5)) +
	remove.y.axis.labels +
	theme(legend.position = c(0.85, 0.125)) +
	ggtitle("(B)")


## Arrange the panel figure
temporal.variation.figure <- grid.arrange(full.temporal.plot, revised.temporal.plot,
																				  nrow = 1, ncol = 2)

## Export the figure
ggsave("Figure 4-Temporal Variation.pdf", 
			 plot = temporal.variation.figure,
			 device = "pdf",
			 path = "/Users/dms/Documents/Research/RSTR-comment/Figures/",
			 width = 8,
			 height = 4.5,
			 units = "in",
			 dpi = 600)


#-------------------------------------------------------------------------#
#                        Site Diversity Response Figure                   #
#--------------------------------------------------------------------------

## Full richness site plot
full.site.richness.plot <- ggplot(full.site.richness.summary, 
																	aes(x = Treatment, y = mean, shape = Order)) +
	stat_summary(aes(group = Site.ID), fun = mean, geom = "path", color = "#440154FF") +
	geom_point(size = 5, color = "#440154FF") +
	scale_y_continuous(breaks = c(4, 8, 12), limits = c(2.5, 12.5)) +
	labs(x = "Treatment", y = "Taxonomic Richness") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	remove.x.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	guides(color = FALSE) +
	ggtitle("(A)")

## Revised richness site plot
revised.site.richness.plot <- ggplot(revised.site.richness.summary, 
																		 aes(x = Treatment, y = mean, shape = Order)) +
	stat_summary(aes(group = Site.ID), fun = mean, geom = "path", color = "#FDE725FF") +
	geom_point(size = 5, color = "#FDE725FF") +
	scale_y_continuous(breaks = c(4, 8, 12), limits = c(2.5, 12.5)) +
	labs(x = "Treatment", y = "Taxonomic Richness") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	remove.all.axis.labels +
	theme(legend.position = c(0.85, 0.825)) +
	guides(color = FALSE) +
	ggtitle("(B)")

## Full diversity site plot
full.site.diversity.plot <- ggplot(full.site.diversity.summary, 
																	 aes(x = Treatment, y = mean, shape = Order)) +
	stat_summary(aes(group = Site.ID), fun = mean, geom = "path", color = "#440154FF") +
	geom_point(size = 5, color = "#440154FF") +
	scale_y_continuous(breaks = c(0.5, 1.0, 1.5), limits = c(0.4, 1.6)) +
	labs(x = "Treatment", y = "Taxonomic Diversity") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	basic.theme +
	theme(legend.position = "none") +
	guides(color = FALSE) +
	ggtitle("(C)")

## Revised diversity site plot
revised.site.diversity.plot <- ggplot(revised.site.diversity.summary, 
																			aes(x = Treatment, y = mean, shape = Order)) +
	stat_summary(aes(group = Site.ID), fun = mean, geom = "path", color = "#FDE725FF") +
	geom_point(size = 5, color = "#FDE725FF") +
	scale_y_continuous(breaks = c(0.5, 1.0, 1.5), limits = c(0.4, 1.6)) +
	labs(x = "Treatment", y = "Taxonomic Diversity") +
	scale_x_discrete(limits = c("Restoration", "Adjacent")) +
	remove.y.axis.labels +
	guides(color = FALSE) +
	ggtitle("(D)")


## Arrange the panel figure
site.response.figure <- grid.arrange(full.site.richness.plot, revised.site.richness.plot,
																		 full.site.diversity.plot, revised.site.diversity.plot,
																		 nrow = 2, ncol = 2)

## Export the figure
ggsave("Figure 5-Site Responses.pdf", 
			 plot = site.response.figure,
			 device = "pdf",
			 path = "/Users/dms/Documents/Research/RSTR-comment/Figures/",
			 width = 9,
			 height = 9,
			 units = "in",
			 dpi = 600)


#=========================================================================#
#                               End of script                             #
#=========================================================================#


## Save final workspace
save.image("~/Documents/Research/RSTR-comment/DMS-RSTR-comment-Workspace.RData")

